/*
 * @(#)FrequencyDialog.java     0.5  01/06/2000
 *
 */
 
import javax.swing.JOptionPane;
import javax.swing.JDialog;
import javax.swing.JTextField;
import java.beans.*;
import java.awt.*;
import java.awt.event.*;

/**
 * This class implements a simple dialog window to input query interval
 *
 * @version 0.5 01/06/2000
 * @author Kai Chen, NLANR
 */
 
public class FrequencyDialog extends JDialog {
    private String typedText;
    private int queryFrequency;
    private int oldQueryFrequency;
    private JOptionPane optionPane;

    Object [] messageArray = null;
    String msgString1;
    String msgString2;
    final JTextField textField;

    public int getValidatedFrequency() {
        return queryFrequency;
    }

    /*
     * change the introduction message of current interval value
     */
    void makeNewMessage() {
	msgString1 = new String ("Current query interval: " + 
				 oldQueryFrequency + " seconds");
        messageArray = new Object[3];
	messageArray[0] = msgString1;
	messageArray[1] = msgString2;
	messageArray[2] = textField;
 
	return;
    }

    public FrequencyDialog(Frame aFrame, int theFrequency) {
        super(aFrame, true);
	oldQueryFrequency = theFrequency;
	
        setTitle("Change Query Interval");

	// construct the message to display on JOpitonPane
	msgString1 = new String ("Current query interval: " +
				 oldQueryFrequency + " seconds");
        msgString2 = new String("Suggested interval range: 5 - 300 seconds");
        textField = new JTextField(5);
        messageArray = new Object[3];
	messageArray[0] = msgString1;
	messageArray[1] = msgString2;
	messageArray[2] = textField;

        final String btnString1 = "OK";
        final String btnString2 = "Cancel";
        Object[] options = {btnString1, btnString2};

        optionPane = new JOptionPane(messageArray, 
				     JOptionPane.QUESTION_MESSAGE,
				     JOptionPane.YES_NO_OPTION,
				     null,
				     options,
				     options[0]);
        setContentPane(optionPane);
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent we) {
		optionPane.setValue(new Integer(
						JOptionPane.CLOSED_OPTION));
            }
        });

        textField.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                optionPane.setValue(btnString1);
            }
        });

        optionPane.addPropertyChangeListener(new PropertyChangeListener() {
            public void propertyChange(PropertyChangeEvent e) {
                String prop = e.getPropertyName();

                if (isVisible() 
		    && (e.getSource() == optionPane)
		    && (prop.equals(JOptionPane.VALUE_PROPERTY) ||
			prop.equals(JOptionPane.INPUT_VALUE_PROPERTY))) {
		    Object value = optionPane.getValue();

                    if (value == JOptionPane.UNINITIALIZED_VALUE) {
                        //ignore reset
                        return;
                    }

                    optionPane.setValue(
					JOptionPane.UNINITIALIZED_VALUE);
		    
                    if (value.equals(btnString1)) {
			typedText = textField.getText();
			boolean success = true;
			try {
			    queryFrequency = Integer.parseInt(typedText);
			    if (queryFrequency < 1) { // too small
				JOptionPane.showMessageDialog(
							      FrequencyDialog.this,
							      "Sorry, " + queryFrequency + 
							      " is not a positive number.",
							      "Try again",
							      JOptionPane.ERROR_MESSAGE);
				success = false;
			    }
			} catch (NumberFormatException ex) {
                            JOptionPane.showMessageDialog(
                                            FrequencyDialog.this,
                                            "Sorry, \"" + typedText + "\" "
                                            + "is not a valid integer.",
					    "Try again",
                                            JOptionPane.ERROR_MESSAGE);
			    success = false;
			}

                        if (success) {
			    oldQueryFrequency = queryFrequency; // keep it
                            setVisible(false); // dismiss window
			    makeNewMessage();
			    optionPane.setMessage(messageArray);
                        } else { 
                            // input was invalid
                            textField.selectAll();
                            typedText = null;
                        }
                    } else { // user closed dialog or clicked cancel
			queryFrequency = 0; // flag for cancellation
                        typedText = null;
                        setVisible(false);
                    }
                }
            }
        });
    }
}




























































































